@@ -6,5 +6,6 @@ class ProcessType(Enum):
     MANUAL_SSO_DETECTION = 2,
     AUTOMATIC_SSO_DETECTION = 3,
     AUTOMATIC_SSO_DETECTION_BY_SEARCH_ENGINE = 4,
-    PRIVACY_DETECTION = 5
+    PRIVACY_DETECTION = 5,
+    SSO_SECURITY_ANALYSIS = 6
 
