@@ -55,12 +55,9 @@ def download_stream(download_url, file_name):
             content_length = int(request_headers["content-length"])
 
         if content_length:
-            logger.info(
-                "Downloading %s. File Size %s "
-                % (file_name, byte_to_human(content_length))
-            )
+            logger.info("Downloading %s. File Size %s " % (file_name, byte_to_human(content_length)))
         else:
-            print("Downloading %s " % file_name)
+            logger.info("Downloading %s " % file_name)
 
         chunk_size = 16 * 1024
         dowloaded_bytes = 0
