@@ -66,6 +66,9 @@ class RestClient:
     path_daemon_ping = "/rest/daemon/ping"
     path_daemon_update_activity = "/rest/daemon/activity"
 
+    # endregion
+    # region Debug Paths
+    debug_path_sso_security_analysis = "/rest/ssosecurityanalysis/debug"
     # endregion
     # endregion
 
@@ -295,21 +298,18 @@ class RestClient:
     # endregion
 
     # region SSO Security Analysis
+    def get_debug_info_sso_security_analysis(self, analysis_run_id, page):
+        response = self.send_get_request(self.debug_path_sso_security_analysis,
+                                         {'analysisrunid': analysis_run_id, 'page': page})
+        return self.extract_response_as_json(response)
+
     def get_next_sso_detection_for_security_analysis_for_run(self, analysis_run_id):
         response = self.send_get_request(self.path_get_next_sso_detection_for_security_analysis,
                                          {'analysisrunid': analysis_run_id})
-        if response.status_code == 200:
-            if response.text is not None and len(response.text) != 0:
-                return response.json()
-            else:
-                return None  # No more sites left!
-        if response.status_code == 409:
-            logger.info("Server requested a retry")
-            raise RetryException()
-        logger.error("Something went wrong (code " + str(response.status_code) + ")")
+        return self.extract_response_as_json(response)
 
     def save_sso_security_analysis(self, analysis_run_id, sso_detection_index: int, result: tuple, screen: bytes, har,
-                                   success=True, error=None):
+                                   success=True, error=None, error_screenshot=None):
         post_data = {'analysisrunid': analysis_run_id, 'ssodetectionid': sso_detection_index, 'authreq': result[0],
                      'authres': result[1], 'success': success, 'error': error}
         files = {}
@@ -317,6 +317,8 @@ class RestClient:
             files['har'] = har
         if screen is not None:
             files['screenshot'] = screen
+        if error_screenshot is not None:
+            files['potentialerrorscreenshot'] = error_screenshot
         response = self.send_post_request_with_files(self.path_save_sso_security_analysis, post_data,
                                                      files)
         if response.status_code == 200 and response.text == "success":
@@ -370,7 +372,8 @@ class RestClient:
         logger.error("Something went wrong updating progress status (" + str(response.status_code) + ")!")
         return False
 
-    def update_progress_of_analysis_using_sso_detection(self, analysis_run_id, sso_detection_id, percent: int, status: str):
+    def update_progress_of_analysis_using_sso_detection(self, analysis_run_id, sso_detection_id, percent: int,
+                                                        status: str):
         response = self.send_post_request(self.path_update_sso_security_analysis_progress,
                                           {'analysisrunid': analysis_run_id, 'ssodetectionid': sso_detection_id,
                                            'percent': int(percent), 'status': status})
@@ -434,6 +437,17 @@ class RestClient:
         logger.error("Something went wrong (code " + str(response.status_code) + ")")
         return None
 
+    def extract_response_as_json(self, response):
+        if response.status_code == 200:
+            if response.text is not None and len(response.text) != 0:
+                return response.json()
+            else:
+                return None  # No more sites left!
+        if response.status_code == 409:
+            logger.info("Server requested a retry")
+            raise RetryException()
+        logger.error("Something went wrong (code " + str(response.status_code) + ")")
+
     # endregion
 
     # region DAEMON METHODS
