@@ -24,20 +24,27 @@ cli.add_argument('--uuid-file', help="Define the place of the file where the cli
                  default=os.path.realpath(os.path.dirname(os.path.abspath(__file__))) + "/.uuid")
 
 
-def start(running_check_element: threading.Event, no_error_check_element: threading.Event, analysis_id: int,
-          backend_info: BackendInformation):
+def start(running_check_element: threading.Event, webdriver_initialisation_error_check_element: threading.Event,
+          analysis_id: int, backend_info: BackendInformation, invalid_config_error_check_element: threading.Event):
     ProcessHelper.prepare_and_run_analysis(backend_info, analysis_id, None, running_check_element,
-                                           no_error_check_element)
+                                           webdriver_initialisation_error_check_element,
+                                           invalid_config_error_check_element)
 
 
 def stop_job(job, rest_client, running_check):
     if job is not None:
         logger.info("Stopping current job...")
-        rest_client.update_latest_activity("Stopping job")
+        try:
+            rest_client.update_latest_activity("Stopping job")
+        except Exception as err:
+            logger.error("Could not report stopping action to brain" + str(err.__class__.__name__ + "!"))
         running_check.clear()
         while job.is_alive():
             sleep(10)
-            rest_client.send_daemon_ping()
+            try:
+                rest_client.send_daemon_ping()
+            except Exception as err:
+                logger.error("Could not ping brain" + str(err.__class__.__name__))
         logger.info("Successfully stopped")
 
 
@@ -89,14 +96,18 @@ def run():
                     if token is None:
                         logger.info("Client not registered yet. Sleeping 30 sec")
                         sleep(30)
+
             logger.info("Got token. Client is initialized")
             rest_client = RestClient(args.server_host, args.server_port, token)
+            logger.info("Checking unfinished work")
             logger.info("Waiting for job...")
             prev_job_id = '-1'
             running_check = threading.Event()
             running_check.set()
-            no_error_check = threading.Event()
-            no_error_check.set()
+            webdriver_initialisation_error_check = threading.Event()
+            webdriver_initialisation_error_check.set()
+            invalid_config_error_check = threading.Event()
+            invalid_config_error_check.set()
             job = None
             stopping_reason = "Shutdown"
             try:
@@ -121,11 +132,13 @@ def run():
                     if job is not None and job.is_alive() and running_check.is_set():
                         current_activity = "Running"
                     if job is not None and not job.is_alive() and current_job_id != "-1":
-                        if no_error_check.is_set():
-                            current_activity = "Finished"
-                        else:
+                        if not webdriver_initialisation_error_check.is_set():
                             stopping_reason = "Client Error Shutdown!"
                             exit(75)
+                        elif not invalid_config_error_check.is_set():
+                            current_activity = "Config is invalid. Reassign after config update"
+                        else:
+                            current_activity = "Finished"
                     rest_client.update_latest_activity(current_activity)
                     if current_job_id == prev_job_id:
                         sleep(30)
@@ -136,15 +149,20 @@ def run():
                         if current_job_id != "-1":
                             rest_client.update_latest_activity("Starting")
                             job = threading.Thread(target=start, args=(
-                                running_check, no_error_check, current_job_id,
-                                BackendInformation(args.server_host, args.server_port, token)))
+                                running_check, webdriver_initialisation_error_check, current_job_id,
+                                BackendInformation(args.server_host, args.server_port, token),
+                                invalid_config_error_check))
                             running_check.set()
                             job.start()
                         prev_job_id = current_job_id
             finally:
                 logger.info("Stopping daemon...")
                 stop_job(job, rest_client, running_check)
-                rest_client.update_latest_activity(stopping_reason)
+                try:
+                    rest_client.update_latest_activity(stopping_reason)
+                except Exception as err:
+                    logger.error("Could not report stopping reason " + stopping_reason + " to brain (" + str(
+                        err.__class__.__name__) + ")!")
                 logger.info("Current job finished")
                 if disp is not None:
                     logger.info("Stopping virtual display")
