@@ -14,7 +14,7 @@ subparsers = cli.add_subparsers(dest="subcommand")
 def create_backend_information(args):
     backend_info = BackendInformation(args.server_host, args.server_port, args.token)
     if not command_line_validator.check_backend_config(backend_info):
-        print("Invalid information!")
+        logger.error("Invalid information!")
         exit(7002)
     return backend_info
 
